<style>
@import url(https://fonts.googleapis.com/css?family=Roboto|Merriweather);
h1, h2, h3 { font-family: Roboto, sans-serif; }
h1 { color: #5b9bd5; }
h2 { color: #ed7d31; }
body {
    font-family: Merriweather, serif;
    max-width: 40rem;
    margin: 2em auto;
    line-height: 1.5;
}
</style>

# Be Happy

## A translation

The word "Happy" translates to:

- Arabic as سعيد.
- Chinese as 高兴.
- Hindi as खुश.
- Russian as счастливый.
- Tamil as சந்தோஷமாக.
